<?php
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Business_Park
 * @since Business Park 1.1.5
 */

if ( ! function_exists( 'business_park_add_team_section' ) ) :
    /**
     * Add team section
     *
     * @since Business Park 1.1.5
     */
    function business_park_add_team_section() {

        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'business_park_section_status', true, 'team_enable' );
        if ( true !== $team_enable ) {
            return false;
        }

        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'business_park_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        business_park_render_team_section( $section_details );
    }
endif;
add_action( 'business_park_primary_content', 'business_park_add_team_section', 85 );


if ( ! function_exists( 'business_park_get_team_section_details' ) ) :
    /**
     * Team section details.
     *
     * @since Business Park 1.1.5
     *
     * @param array $input Team section details.
     */
    function business_park_get_team_section_details( $input ) {
        $options = business_park_get_theme_options();

        // Team type
        $team_content_type    = $options['team_content_type'];

        $content = array();
        switch ( $team_content_type ) {
            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'team_content_page_'.$i ] ) ) {
                        $id = $options[ 'team_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );

                $posts = get_posts( $args );

                if ( ! empty( $posts ) ) {
                    $i = 1;
                    foreach ( $posts as $key => $post ) {
                        $post_id = $post->ID;
                        $img_array = null;

                        if ( has_post_thumbnail( $post_id ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'business-park-team' );
                        } else {
                            $img_array = business_park_dummy_image( 1920, 1080 );
                        }

                        if ( isset( $img_array ) ) {
                            $content[$i]['img_array'] = $img_array;
                        }

                        $content[$i]['url']      = get_permalink( $post_id );
                        $content[$i]['title']    = get_the_title( $post_id );

                        if ( isset( $options[ 'team_position_'.$i ] ) ) {
                            $content[$i]['position']  = $options[ 'team_position_'.$i];
                        }

                        $i++;
                    }
                }
            break;

            default:
            break;
        }
        if ( ! empty( $content ) ) {
            $input = $content;
        }

        return $input;
    }
endif;
// Team section content details.
add_filter( 'business_park_filter_team_section_details', 'business_park_get_team_section_details' );


if ( ! function_exists( 'business_park_render_team_section' ) ) :
    /**
     * Start section id .about
     *
     * @return string about content
     * @since Business Park 1.1.5
     *
     */
    function business_park_render_team_section( $content_details = array() ) {
        $options = business_park_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        }
        
        ?>
        <section id="team">
            <div class="overlay"></div>
            <div class="container">
                <header class="entry-header">
                  <h2 class="entry-title"><?php echo esc_html( $options['team_section_title'] );?></h2>
                </header>
                <div class="entry-content">
                    <?php foreach ( $content_details as $content ):?>
                    <div class="four-col">
                        <div class="team-member">
                            <?php if ( ! empty( $content['img_array'] ) ) { ?>
                                <div class="team-image">
                                    <a href="<?php echo esc_url( $content['url'] );?>">
                                        <img width="<?php echo esc_attr( $content['img_array'][1] );?>" height="<?php echo esc_attr( $content['img_array'][2] );?>" src="<?php echo esc_url( $content['img_array'][0] ); ?>" />
                                    </a>
                                </div><!-- end .team-image -->
                            <?php }?>
                            <div class="team-description">
                                <?php if ( ! empty( $content['position'] ) ) { ?>
                                    <span class="position"><?php echo esc_html( $content['position'] );?></span>
                                <?php }?>
                                <?php if ( ! empty( $content['title'] ) ) { ?>
                                    <h4 class="name"><a href="<?php echo esc_url( $content['url'] );?>"><?php echo esc_html( $content['title'] );?></a></h4>
                                <?php }?>
                            </div><!-- end .team-description -->
                        </div><!-- end .team-meber -->
                    </div><!-- end .four-col -->
                    <?php endforeach; ?>
                <div class="clear"></div>
                </div><!-- end .entry-content -->
            </div><!-- end .container -->
        </section><!-- end #team -->
<?php
    }
endif;
